==> lxqt-globalkeys_0.14.0.orig.tar.gz: lxqt-globalkeys-0.14.0/config/translations/lxqt-config-globalkeyshortcuts_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>Виклик DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Клієнт</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Cкорочення</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Редагувати дію</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Cкорочення:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Опис:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Включено</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Команда</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;Повідомлення DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Ко&amp;манда:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>Се&amp;рвіс:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>Шля&amp;х:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Інтерфейс:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Метод:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Управління глобальними діями</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation>Додати ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation>Змінити ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation>Поміняти</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation>Поведінка багатьох дій:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="123"/>
        <source>First</source>
        <translation>Перша</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="128"/>
        <source>Last</source>
        <translation>Остання</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="133"/>
        <source>None</source>
        <translation>Нічого</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="138"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="176"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
</TS>

==> lxqt-globalkeys_0.16.0.orig.tar.gz: lxqt-globalkeys-0.16.0/config/translations/lxqt-config-globalkeyshortcuts_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="52"/>
        <source>DBus call</source>
        <translation>Виклик DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="53"/>
        <source>Client</source>
        <translation>Клієнт</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="143"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="146"/>
        <source>Shortcut</source>
        <translation>Cкорочення</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="149"/>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="152"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="155"/>
        <source>Info</source>
        <translation>Інформація</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Редагувати дію</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Cкорочення:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Опис:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Включено</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Команда</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;Повідомлення DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Ко&amp;манда:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>Се&amp;рвіс:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>Шля&amp;х:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Інтерфейс:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Метод:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Управління глобальними діями</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="55"/>
        <source>Add ...</source>
        <translation>Додати ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="65"/>
        <source>Remove</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="75"/>
        <source>Modify ...</source>
        <translation>Змінити ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Swap</source>
        <translation>Поміняти</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="118"/>
        <source>Multiple actions behaviour:</source>
        <translation>Поведінка багатьох дій:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="126"/>
        <source>First</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation type="unfinished">Перша</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="131"/>
        <source>Last</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation type="unfinished">Остання</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="136"/>
        <source>None</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation type="unfinished">Нічого</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="141"/>
        <source>All</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation type="unfinished">Все</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="166"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="186"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="187"/>
        <source>Restore Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="188"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
